@@ -23,8 +23,8 @@
 
 #include <glom/frame_glom.h>
 #include <glom/application.h>
-#include <glom/dialog_import_csv.h>
-#include <glom/dialog_import_csv_progress.h>
+#include <glom/import_csv/dialog_import_csv.h>
+#include <glom/import_csv/dialog_import_csv_progress.h>
 #include <libglom/appstate.h>
 
 #include <libglom/connectionpool.h>
@@ -78,6 +78,7 @@ namespace Glom
 Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : PlaceHolder(cobject, builder),
   m_pLabel_Table(0),
+  m_box_header(0),
   m_box_footer(0),
   m_pLabel_Mode(0),
   m_pLabel_userlevel(0),
@@ -89,8 +90,10 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   m_pLabel_FoundCount(0),
   m_pButton_FindAll(0),
   m_pBox_Mode(0),
+#ifndef GLOM_ENABLE_MAEMO
   m_pBox_Tables(0),
   m_pDialog_Tables(0),
+#endif //GLOM_ENABLE_MAEMO
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   m_pDialog_Reports(0),
   m_pDialogLayoutReport(0),
@@ -111,27 +114,43 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   //Load widgets from glade file:
   builder->get_widget("label_table_name", m_pLabel_Table);
 
+  builder->get_widget("hbox_header", m_box_header);
   builder->get_widget("hbox_footer", m_box_footer);
   builder->get_widget("label_mode", m_pLabel_Mode);
   builder->get_widget("label_user_level", m_pLabel_userlevel);
   
-  //Hide the footer on maemo (It takes too much space),
+  //Hide unnecessary widgets on maemo that take too much space,
   //and reduce the border width:
   #ifdef GLOM_ENABLE_MAEMO
+  m_box_header->hide();
   m_box_footer->hide();
   set_border_width(Glom::Utils::DEFAULT_SPACING_LARGE);
   #endif
 
-  builder->get_widget("hbox_quickfind", m_pBox_QuickFind);
-  m_pBox_QuickFind->hide();
-
-  builder->get_widget("entry_quickfind", m_pEntry_QuickFind);
+  //QuickFind widgets:
+  //We don't use Glade for these, so it easier to modify them for the Maemo port.
+  m_pBox_QuickFind = Gtk::manage(new Gtk::HBox(false, 6));
+  Gtk::Label* label = Gtk::manage(new Gtk::Label(_("Quick Find")));
+  m_pBox_QuickFind->pack_start(*label, Gtk::PACK_SHRINK);
+  m_pEntry_QuickFind = Gtk::manage(new Gtk::Entry());
   m_pEntry_QuickFind->signal_activate().connect(
    sigc::mem_fun(*this, &Frame_Glom::on_button_quickfind) ); //Pressing Enter here is like pressing Find.
 
-  builder->get_widget("button_quickfind", m_pButton_QuickFind);
+  m_pBox_QuickFind->pack_start(*m_pEntry_QuickFind, Gtk::PACK_EXPAND_WIDGET);
+  m_pButton_QuickFind = Gtk::manage(new Gtk::Button(_("_Find"), true));
   m_pButton_QuickFind->signal_clicked().connect(
     sigc::mem_fun(*this, &Frame_Glom::on_button_quickfind) );
+  m_pBox_QuickFind->pack_start(*m_pButton_QuickFind, Gtk::PACK_SHRINK);
+  
+  m_pBox_QuickFind->show_all_children();
+  m_pBox_QuickFind->hide();
+
+  #ifndef GLOM_ENABLE_MAEMO
+  PlaceHolder* placeholder_quickfind = 0;
+  builder->get_widget_derived("vbox_quickfind", placeholder_quickfind);
+  placeholder_quickfind->add(*m_pBox_QuickFind);
+  #endif //GLOM_ENABLE_MAEMO
+
 
   builder->get_widget("hbox_records_count", m_pBox_RecordsCount);
   builder->get_widget("label_records_count", m_pLabel_RecordsCount);
@@ -148,7 +167,6 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 
   m_Notebook_Find.signal_find_criteria.connect(sigc::mem_fun(*this, &Frame_Glom::on_notebook_find_criteria));
   m_Notebook_Find.show();
-
   m_Notebook_Data.signal_record_details_requested().connect(sigc::mem_fun(*this, &Frame_Glom::on_notebook_data_record_details_requested));
   m_Notebook_Data.signal_switch_page().connect(sigc::mem_fun(*this, &Frame_Glom::on_notebook_data_switch_page));
   m_Notebook_Data.show();
@@ -163,17 +181,20 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 
 Frame_Glom::~Frame_Glom()
 {
+#ifndef GLOM_ENABLE_MAEMO
   if(m_pBox_Tables)
     remove_view(m_pBox_Tables);
 
-  remove_view(&m_Notebook_Data); //Also a composite view.
-  remove_view(&m_Notebook_Find); //Also a composite view.
-
   if(m_pDialog_Tables)
   {
     delete m_pDialog_Tables;
     m_pDialog_Tables = 0;
   }
+#endif //GLOM_ENABLE_MAEMO
+
+  remove_view(&m_Notebook_Data); //Also a composite view.
+  remove_view(&m_Notebook_Find); //Also a composite view.
+
 
   if(m_pDialogConnection)
   {
@@ -265,8 +286,10 @@ void Frame_Glom::set_databases_selected(const Glib::ustring& strName)
 
 void Frame_Glom::on_box_tables_selected(const Glib::ustring& strName)
 {
+#ifndef GLOM_ENABLE_MAEMO
   if(m_pDialog_Tables)
     m_pDialog_Tables->hide();
+#endif //GLOM_ENABLE_MAEMO
 
   show_table(strName);
 }
@@ -1296,18 +1319,18 @@ void Frame_Glom::do_menu_Navigate_Table(bool open_default)
   if(open_default)
     default_table_name = get_document()->get_default_table();
   
+#ifndef GLOM_ENABLE_MAEMO
   //Create the dialog, if it has not already been created:
   if(!m_pBox_Tables)
   {
     Utils::get_glade_widget_derived_with_warning("box_navigation_tables", m_pBox_Tables);
-    m_pDialog_Tables = new Dialog_Glom(m_pBox_Tables, _("Tables"));
+    m_pDialog_Tables = new Window_BoxHolder(m_pBox_Tables, _("Tables"));
     m_pDialog_Tables->signal_hide().connect(sigc::mem_fun(*this, &Frame_Glom::on_dialog_tables_hide));
 
     Gtk::Window* pWindow = get_app_window();
     if(pWindow)
       m_pDialog_Tables->set_transient_for(*pWindow);
 
-    m_pDialog_Tables->get_vbox()->pack_start(*m_pBox_Tables);
     m_pDialog_Tables->set_default_size(300, 400);
     m_pBox_Tables->show_all();
     add_view(m_pBox_Tables);
@@ -1320,6 +1343,7 @@ void Frame_Glom::do_menu_Navigate_Table(bool open_default)
     BusyCursor busy_cursor(get_app_window());
     m_pBox_Tables->init_db_details();
   }
+  #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   //Let the user choose a table:
   //m_pDialog_Tables->set_policy(false, true, false); //TODO_port
@@ -1331,8 +1355,13 @@ void Frame_Glom::do_menu_Navigate_Table(bool open_default)
   }
   else
   {
+    #ifndef GLOM_ENABLE_CLIENT_ONLY
     m_pDialog_Tables->show();
+    #else
+    //For Maemo: TODO
+    #endif // !GLOM_ENABLE_CLIENT_ONLY
   }
+
 }
 
 const Gtk::Window* Frame_Glom::get_app_window() const
@@ -1451,30 +1480,32 @@ void Frame_Glom::on_userlevel_changed(AppState::userlevels userlevel)
 
 void Frame_Glom::show_table_title()
 {
-  if(get_document())
+  Document* document = dynamic_cast<Document*>(get_document());
+  if(!document)
+    return;
+
+  //Show the table title:
+  Glib::ustring table_label = document->get_table_title(m_table_name);
+  if(!table_label.empty())
   {
-    //Show the table title:
-    Glib::ustring table_label = get_document()->get_table_title(m_table_name);
-    if(!table_label.empty())
-    {
-      Document* document = dynamic_cast<Document*>(get_document());
-      if(document)
-      {
-        if(document->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
-          table_label += " (" + m_table_name + ")"; //Show the table name as well, if in developer mode.
-      }
-    }
-    else //Use the table name if there is no table title.
-      table_label = m_table_name;
+    if(document->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+      table_label += " (" + m_table_name + ")"; //Show the table name as well, if in developer mode.
+  }
+  else //Use the table name if there is no table title.
+    table_label = m_table_name;
 
 #ifdef GLOM_ENABLE_MAEMO
-    // xx-large is too large on maemo, taking away too much (vertical)
-    // screen estate
-    m_pLabel_Table->set_markup("<b>" + table_label + "</b>");
+  //Show the system's human-readable title and the table title in 
+  //the window's title bar:
+  Gtk::Window* app = get_app_window();
+  if(app)
+    app->set_title(document->get_name() + ": " + table_label);
+
+  // xx-large is too large on maemo, using far too much (vertical) space.
+  // We hide this anyway: m_pLabel_Table->set_markup("<b>" + table_label + "</b>");
 #else
-    m_pLabel_Table->set_markup("<b><span size=\"xx-large\">" + table_label + "</span></b>"); //Show the table title in large text, because it's very important to the user.
+  m_pLabel_Table->set_markup("<b><span size=\"xx-large\">" + table_label + "</span></b>"); //Show the table title in large text, because it's very important to the user.
 #endif
-  }
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -1784,7 +1815,7 @@ void Frame_Glom::on_menu_developer_reports()
   if(!m_pBox_Reports)
   {
     Utils::get_glade_developer_widget_derived_with_warning("box_reports", m_pBox_Reports);
-    m_pDialog_Reports = new Dialog_Glom(m_pBox_Reports);
+    m_pDialog_Reports = new Window_BoxHolder(m_pBox_Reports);
     m_pDialog_Reports->set_transient_for(*(get_app_window()));
 
     Utils::get_glade_developer_widget_derived_with_warning("window_report_layout", m_pDialogLayoutReport);
@@ -1792,7 +1823,6 @@ void Frame_Glom::on_menu_developer_reports()
     m_pDialogLayoutReport->set_transient_for(*(get_app_window()));
     m_pDialogLayoutReport->signal_hide().connect( sigc::mem_fun(*this, &Frame_Glom::on_dialog_layout_report_hide) );
 
-    m_pDialog_Reports->get_vbox()->pack_start(*m_pBox_Reports);
     m_pDialog_Reports->set_default_size(300, 400);
     m_pBox_Reports->show_all();
 
@@ -1817,9 +1847,8 @@ void Frame_Glom::on_menu_developer_print_layouts()
   if(!m_pBox_PrintLayouts)
   {
     Utils::get_glade_developer_widget_derived_with_warning("box_print_layouts", m_pBox_PrintLayouts);
-    m_pDialog_PrintLayouts = new Dialog_Glom(m_pBox_PrintLayouts);
+    m_pDialog_PrintLayouts = new Window_BoxHolder(m_pBox_PrintLayouts);
 
-    m_pDialog_PrintLayouts->get_vbox()->pack_start(*m_pBox_PrintLayouts);
     m_pDialog_PrintLayouts->set_default_size(300, 400);
     m_pBox_PrintLayouts->show_all();
     add_view(m_pBox_PrintLayouts);
@@ -2832,5 +2861,10 @@ bool Frame_Glom::get_viewing_details() const
   return (m_Notebook_Data.get_current_view() == Notebook_Data::DATA_VIEW_Details);
 }
 
+Glib::ustring Frame_Glom::get_shown_table_name() const
+{
+  return m_table_name;
+}
+
 } //namespace Glom
 
