@@ -1,6 +1,6 @@
 /* Glom
  *
- * Copyright (C) 2001-2004 Murray Cumming
+ * Copyright (C) 2001-2009 Murray Cumming
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,7 +24,7 @@
 #include <libglom/data_structure/field.h>
 #include <libglom/data_structure/relationship.h>
 #include <libglom/data_structure/glomconversions.h>
-#include <glom/mode_data/dialog_layout_details.h>
+#include <glom/mode_design/layout/dialog_layout_details.h>
 #include <glom/glade_utils.h>
 #include <glom/utils_ui.h>
 #include <glom/glom_privs.h>
@@ -37,30 +37,24 @@ namespace Glom
 {
 
 Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
-: m_HBox(false, Utils::DEFAULT_SPACING_SMALL),
-  m_HBox_Sidebar (false, Utils::DEFAULT_SPACING_SMALL),
+: m_hbox_content(false, Utils::DEFAULT_SPACING_SMALL),
+#ifndef GLOM_ENABLE_MAEMO
+  m_hbox_buttons(false, Utils::DEFAULT_SPACING_SMALL),
   m_Button_New(Gtk::Stock::ADD),
   m_Button_Del(Gtk::Stock::DELETE),
   m_Button_Nav_First(Gtk::Stock::GOTO_FIRST),
   m_Button_Nav_Prev(Gtk::Stock::GO_BACK),
   m_Button_Nav_Next(Gtk::Stock::GO_FORWARD),
   m_Button_Nav_Last(Gtk::Stock::GOTO_LAST),
+#endif //GLOM_ENABLE_MAEMO
   m_bDoNotRefreshRelated(false),
   m_ignore_signals(true)
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  ,m_design_mode(false)
+  , m_design_mode(false)
 #endif
 {
   m_layout_name = "details";
 
-  m_Button_New.set_tooltip_text(_("Create a new record."));
-  m_Button_Del.set_tooltip_text(_("Remove this record."));
-  m_Button_Nav_First.set_tooltip_text(_("View the first record in the list."));
-  m_Button_Nav_Prev.set_tooltip_text(_("View the previous record in the list."));
-  m_Button_Nav_Next.set_tooltip_text(_("View the next record in the list."));
-  m_Button_Nav_Last.set_tooltip_text(_("View the last record in the list."));
-  
-
   add_view(&m_FlowTable); //Allow this to access the document too.
 
   m_FlowTable.set_columns_count(1); //Sub-groups will have multiple columns (by default, there is one sub-group, with 2 columns).
@@ -71,49 +65,32 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
 
   //m_ScrolledWindow.set_border_width(Utils::DEFAULT_SPACING_SMALL);
 #ifdef GLOM_ENABLE_MAEMO
-  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC); /* Allow horizontal scrolling in maemo because the screen is rather small and there might be some database UIs that don't fit horizontally. Such a UI may be concidered non-maemo-friendly, but it can still be fully viewed this way. */
+  // Allow horizontal scrolling in maemo because the screen is rather small and 
+  // there might be some database UIs that don't fit horizontally. Such a UI may 
+  // be considered non-maemo-friendly, but it can still be fully viewed this way.
+  // TODO: Prevent the need for horizontal scrolling.
+  m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
 #else
-  m_ScrolledWindow.set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC); /* Allow vertical scrolling, but never scroll horizontally. */
+  // Allow vertical scrolling, but never scroll horizontally:
+  m_ScrolledWindow.set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC); 
 #endif
   m_ScrolledWindow.set_shadow_type(Gtk::SHADOW_NONE); //SHADOW_IN is Recommended by the GNOME HIG, but looks odd.
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  m_HBox_Sidebar.pack_start(m_Dragbar, Gtk::PACK_SHRINK);
+  m_hbox_content.pack_start(m_Dragbar, Gtk::PACK_SHRINK);
   m_Dragbar.hide();
 #endif
 
-  m_HBox_Sidebar.pack_start(m_ScrolledWindow);
+  m_hbox_content.pack_start(m_ScrolledWindow);
   m_ScrolledWindow.add(m_FlowTable);
   // The FlowTable does not support native scrolling, so gtkmm adds it to a
   // viewport first that also has some shadow we do not want.
   Gtk::Viewport* viewport = dynamic_cast<Gtk::Viewport*>(m_FlowTable.get_parent());
-  if(viewport) viewport->set_shadow_type(Gtk::SHADOW_NONE);
+  if(viewport)
+    viewport->set_shadow_type(Gtk::SHADOW_NONE);
 
-  //Add or delete record:
-  m_HBox.pack_start(m_Button_New, Gtk::PACK_SHRINK);
-  m_HBox.pack_start(m_Button_Del,  Gtk::PACK_SHRINK);
 
-   //Link buttons to handlers:
-  m_Button_New.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_new));
-  m_Button_Del.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_del));
-
-  //Navigation:
-  if(bWithNavButtons)
-  {
-    m_HBox.pack_end(m_Button_Nav_Last, Gtk::PACK_SHRINK);
-    m_HBox.pack_end(m_Button_Nav_Next, Gtk::PACK_SHRINK);
-    m_HBox.pack_end(m_Button_Nav_Prev, Gtk::PACK_SHRINK);
-    m_HBox.pack_end(m_Button_Nav_First, Gtk::PACK_SHRINK);
-  }
-
-  //Link buttons to handlers:
-  m_Button_Nav_First.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_nav_first));
-  m_Button_Nav_Prev.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_nav_prev));
-  m_Button_Nav_Next.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_nav_next));
-  m_Button_Nav_Last.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_nav_last));
-
-  pack_start(m_HBox_Sidebar);
-  pack_start(m_HBox, Gtk::PACK_SHRINK);
+  pack_start(m_hbox_content);
 
   m_FlowTable.signal_field_edited().connect( sigc::mem_fun(*this,  &Box_Data_Details::on_flowtable_field_edited) );
   m_FlowTable.signal_field_open_details_requested().connect( sigc::mem_fun(*this,  &Box_Data_Details::on_flowtable_field_open_details_requested) );
@@ -130,6 +107,41 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
 
   m_FlowTable.signal_script_button_clicked().connect( sigc::mem_fun(*this, &Box_Data_Details::on_flowtable_script_button_clicked) );
 
+
+#ifndef GLOM_ENABLE_MAEMO
+  m_Button_New.set_tooltip_text(_("Create a new record."));
+  m_Button_Del.set_tooltip_text(_("Remove this record."));
+  m_Button_Nav_First.set_tooltip_text(_("View the first record in the list."));
+  m_Button_Nav_Prev.set_tooltip_text(_("View the previous record in the list."));
+  m_Button_Nav_Next.set_tooltip_text(_("View the next record in the list."));
+  m_Button_Nav_Last.set_tooltip_text(_("View the last record in the list."));
+
+  //Add or delete record:
+  m_hbox_buttons.pack_start(m_Button_New, Gtk::PACK_SHRINK);
+  m_hbox_buttons.pack_start(m_Button_Del,  Gtk::PACK_SHRINK);
+
+  //Link buttons to handlers:
+  m_Button_New.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_new));
+  m_Button_Del.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_del));
+
+  //Navigation:
+  if(bWithNavButtons)
+  {
+    m_hbox_buttons.pack_end(m_Button_Nav_Last, Gtk::PACK_SHRINK);
+    m_hbox_buttons.pack_end(m_Button_Nav_Next, Gtk::PACK_SHRINK);
+    m_hbox_buttons.pack_end(m_Button_Nav_Prev, Gtk::PACK_SHRINK);
+    m_hbox_buttons.pack_end(m_Button_Nav_First, Gtk::PACK_SHRINK);
+  }
+
+  //Link buttons to handlers:
+  m_Button_Nav_First.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_nav_first));
+  m_Button_Nav_Prev.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_nav_prev));
+  m_Button_Nav_Next.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_nav_next));
+  m_Button_Nav_Last.signal_clicked().connect(sigc::mem_fun(*this, &Box_Data_Details::on_button_nav_last));
+
+  pack_start(m_hbox_buttons, Gtk::PACK_SHRINK);
+#endif //GLOM_ENABLE_MAEMO
+
   m_ignore_signals = false;
 }
 
@@ -285,8 +297,10 @@ bool Box_Data_Details::fill_from_database()
       Privileges table_privs = Privs::get_current_privs(m_table_name);
 
       //Enable/Disable record creation and deletion:
+      #ifndef GLOM_ENABLE_MAEMO
       m_Button_New.set_sensitive(table_privs.m_create);
       m_Button_Del.set_sensitive(table_privs.m_delete);
+      #endif //GLOM_ENABLE_MAEMO
 
       if(table_privs.m_view)
       {
@@ -408,6 +422,7 @@ bool Box_Data_Details::fill_from_database()
   return bResult;
 }
 
+#ifndef GLOM_ENABLE_MAEMO
 void Box_Data_Details::on_button_new()
 {
   if(!confirm_discard_unstored_data())
@@ -494,6 +509,7 @@ void Box_Data_Details::on_button_nav_last()
   if(confirm_discard_unstored_data())
     signal_nav_last().emit();
 }
+#endif //GLOM_ENABLE_MAEMO
 
 Gnome::Gda::Value Box_Data_Details::get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const
 {
@@ -580,6 +596,7 @@ void Box_Data_Details::on_related_record_added(Gnome::Gda::Value /* strKeyValue
   m_bDoNotRefreshRelated = bDoNotRefreshRelated;
 }
 
+#ifndef GLOM_ENABLE_MAEMO
 Box_Data_Details::type_signal_void Box_Data_Details::signal_nav_first()
 {
   return m_signal_nav_first;
@@ -604,6 +621,7 @@ Box_Data_Details::type_signal_record_deleted Box_Data_Details::signal_record_del
 {
   return m_signal_record_deleted; 
 }
+#endif //GLOM_ENABLE_MAEMO
 
 Box_Data_Details::type_signal_requested_related_details Box_Data_Details::signal_requested_related_details()
 {
@@ -691,8 +709,10 @@ void Box_Data_Details::on_flowtable_script_button_clicked(const sharedptr<const
     }
     else
     {
+      #ifndef GLOM_ENABLE_MAEMO
       //Tell the parent to do something appropriate, such as show another record:
       signal_record_deleted().emit(primary_key_value);
+      #endif
     }
   }
 }
